# Changelog

## 0.0.2 (2026-03-16)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/et0and/address-python/compare/v0.0.1...v0.0.2)

### Chores

* configure new SDK language ([9d61f07](https://github.com/et0and/address-python/commit/9d61f07cf990e2064740ad99b31bf47cbeb84a27))
* update SDK settings ([4a0816c](https://github.com/et0and/address-python/commit/4a0816ccb07072073bfcb330fc093d53be4bd1ea))
* update SDK settings ([7c0d2c3](https://github.com/et0and/address-python/commit/7c0d2c31ddf0496a10e0911ef04439a953994445))
